// Copyright (c) 2024 Infineon Technologies AG. All rights reserved
// Licensed under the Apache License, Version 2.0, see APACHE_LICENSE for details.
// SPDX-License-Identifier: Apache-2.0

/*******************************************************************************
* Header Files
*******************************************************************************/
#include "cybsp.h"
#include "cy_tcpwm_pwm.h"
#include "cy_trigmux.h"


/*******************************************************************************
* Macros
*******************************************************************************/

/*******************************************************************************
* Global Variables
*******************************************************************************/


/*******************************************************************************
* Function Prototypes
*******************************************************************************/


/*******************************************************************************
* Function Definitions
*******************************************************************************/

/*******************************************************************************
* Function Name: handle_error
********************************************************************************
* Summary:
*  User defined error handling function.
*
* Parameters:
*  status - status for evaluation.
*
* Return:
*  void
*
*******************************************************************************/
void handle_error(cy_rslt_t status)
{
    if (CY_RSLT_SUCCESS != status)
    {
        /* Halt the CPU while debugging */
        CY_ASSERT(0);
    }
}

/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
* This is the main function for the CPU. It configures the PWM and puts the CPU
* in Sleep mode to save power.
*
* Parameters:
*  void
*
* Return:
*  int
*
*******************************************************************************/
int main(void)
{
    /* API return code */
    cy_rslt_t result;

    /* Initialize the device and board peripherals */
    result = cybsp_init();
    handle_error(result);

    /* Enable global interrupts */
    __enable_irq();

    /* Initialize the PWM */
		Cy_TCPWM_PWM_Init(PWM_LED1_HW, PWM_LED1_NUM, &PWM_LED1_config);
		
		/* Enable the initialized PWM */
    Cy_TCPWM_PWM_Enable(PWM_LED1_HW, PWM_LED1_NUM);
		
		/* Then start the PWM */
		Cy_TCPWM_TriggerStart_Single(PWM_LED1_HW, PWM_LED1_NUM);
    for (;;)
    {
        /* Put the CPU into sleep mode to save power */
        Cy_SysPm_Sleep(0UL);
    }
}


/* [] END OF FILE */